# NekoMimi Python Module

this is a python package to make your code look nicer and smaller
supports most used modules to make it easy to work with them and to have less of that copy-paste action

currently in alpha phase

please note that this shouldn't be used by the public in this phase

```python
  pip3 install NekoMimi
```
